##  Creating a Workspace View
Before you start, ensure that all fact sheet types have meaningful descriptions. When users apply a workspace view that includes multiple fact sheet types from the inventory, they're prompted to select one type to get started. Descriptions help users, especially infrequent ones, understand the differences between fact sheet types and how to use each one. To learn how to edit descriptions, see [Fact Sheet Description](https://help.sap.com/docs/leanix/ea/meta-model-configuration?locale=en-US&state=PRODUCTION&version=CLOUD "Configure the meta model to adjust it to your requirements.").
To create a workspace view, follow these steps:
  1. In the administration area, navigate to the Workspace Views section.
  2. Click Create Workspace View.
  3. Enter a name and, optionally, a description for the workspace view. These details will be visible to users.
  4. Select fact sheets to include in the workspace view by specifying the following:
     * Fact sheet types
     * Sections and subsections within each fact sheet type
     * Specific fact sheets or all fact sheets of that type (using inventory filters)
  5. Select reports, dashboards, and diagrams to include in the workspace view. If you add multiple dashboards, you can select a default one.
  6. In the Visibility section, define who should have access to the workspace view: all users or only users with specific roles. You can also set this view as default for specific roles.
  7. Decide whether to activate the workspace view after creation or save it as a draft.
     * Create as Draft: The workspace view won't be available to non-admin users. You can preview it before activating and finish editing later.
     * Create and Activate: The workspace view will be created as active.


Once a workspace view is created, it appears on the right side of the navigation bar, next to the fact sheet search field.
